window.Gleam.initSearch([{"doc":"eventsourcing_sqlite","title":"eventsourcing_sqlite","content":"&lt;h1 align=&quot;center&quot;&gt;Eventsourcing SQLite&lt;/h1&gt;\n\n&lt;div align=&quot;center&quot;&gt;\n  ✨ &lt;strong&gt;Event Sourcing Library for Gleam with SQLite&lt;/strong&gt; ✨\n&lt;/div&gt;\n\n&lt;div align=&quot;center&quot;&gt;\n  A Gleam library for building event-sourced systems using SQLite as the event store.\n&lt;/div&gt;\n\n&lt;br /&gt;\n\n&lt;div align=&quot;center&quot;&gt;\n  &lt;a href=&quot;https://hex.pm/packages/eventsourcing_sqlite&quot;&gt;\n    &lt;img src=&quot;https://img.shields.io/hexpm/v/eventsourcing_sqlite&quot; alt=&quot;Available on Hex&quot; /&gt;\n  &lt;/a&gt;\n  &lt;a href=&quot;https://hexdocs.pm/eventsourcing_sqlite&quot;&gt;\n    &lt;img src=&quot;https://img.shields.io/badge/hex-docs-ffaff3&quot; alt=&quot;Documentation&quot; /&gt;\n  &lt;/a&gt;\n&lt;/div&gt;\n\n---\n\n## Table of contents\n\n- [Introduction](#introduction)\n- [Features](#features)\n- [Concurrency Safety](#concurrency-safety)\n- [Philosophy](#philosophy)\n- [Installation](#installation)\n- [Support](#support)\n- [Contributing](#contributing)\n- [License](#license)\n\n## Introduction\n\n`eventsourcing_sqlite` is a Gleam library designed to help developers build event-sourced systems using SQLite. Event sourcing is a pattern where changes to the application&#39;s state are stored as an immutable sequence of events. This approach provides several benefits, including complete audit trails, simplified debugging, and the ability to reconstruct past states.\n\n## Features\n\n- **Event Sourcing**: Build systems based on the event sourcing pattern.\n- **SQLite Event Store**: Robust event store implementation using SQLite.\n- **Command Handling**: Handle commands and produce events with robust error handling.\n- **Event Application**: Apply events to update aggregates.\n- **Snapshotting**: Optimize aggregate rebuilding with configurable snapshots.\n- **Type-safe Error Handling**: Comprehensive error types and Result-based API.\n\n## Concurrency Safety\n\nThis driver is designed to be used in a single-threaded environment. It is not safe to use this driver in a multi-threaded environment.\n\n## Philosophy\n\neventsourcing_sqlite is designed to make building event-sourced systems easy and intuitive.\nIt encourages a clear separation between command handling and event application,\nmaking your code more maintainable and testable.\n\n## Installation\n\nAdd eventsourcing_sqlite to your Gleam projects from the command line:\n\n``` sh\ngleam add eventsourcing_sqlite\n```\n\n## Support\n\neventsourcing_sqlite is built by Renatillas.\nContributions are very welcome!\nIf you&#39;ve spotted a bug, or would like to suggest a feature,\nplease open an issue or a pull request.\n\n## Contributing\n\nContributions are welcome! Please follow these steps:\n\n1. Fork the repository.\n2. Create a new branch (git checkout -b my-feature-branch).\n3. Make your changes and commit them (git commit -m &#39;Add new feature&#39;).\n4. Push to the branch (git push origin my-feature-branch).\n5. Open a pull request.\n\nPlease ensure your code adheres to the project&#39;s coding standards and includes appropriate tests.\n\n## License\n\nThis project is licensed under the MIT License. See the LICENSE file for details.\n","url":"index.html"},{"doc":"eventsourcing_sqlite","title":"Metadata","content":"pub type Metadata =\n  List(#(String, String))\n\n\nSynonyms:\neventsourcing_sqlite.Metadata\neventsourcing_sqlite Metadata","url":"eventsourcing_sqlite.html#Metadata"},{"doc":"eventsourcing_sqlite","title":"create_event_table","content":"pub fn create_event_table(\n  sqlite_store: SqliteStore(a, b, c, d),\n) -&gt; Result(Nil, EventSourcingError(e))\n\nSynonyms:\neventsourcing_sqlite.create_event_table\neventsourcing_sqlite create_event_table","url":"eventsourcing_sqlite.html#create_event_table"},{"doc":"eventsourcing_sqlite","title":"create_snapshot_table","content":"pub fn create_snapshot_table(\n  sqlite_store: SqliteStore(a, b, c, d),\n) -&gt; Result(Nil, EventSourcingError(d))\n\nSynonyms:\neventsourcing_sqlite.create_snapshot_table\neventsourcing_sqlite create_snapshot_table","url":"eventsourcing_sqlite.html#create_snapshot_table"},{"doc":"eventsourcing_sqlite","title":"load_events","content":"pub fn load_events(\n  sqlite_store: SqliteStore(a, b, c, d),\n  tx: Connection,\n  aggregate_id: String,\n  start_from: Int,\n) -&gt; Result(List(EventEnvelop(c)), EventSourcingError(e))\n\nSynonyms:\neventsourcing_sqlite.load_events\neventsourcing_sqlite load_events","url":"eventsourcing_sqlite.html#load_events"},{"doc":"eventsourcing_sqlite","title":"new","content":"pub fn new(\n  sqlight_connection_string connection_string: String,\n  event_encoder event_encoder: fn(a) -&gt; String,\n  event_decoder event_decoder: Decoder(a),\n  event_type event_type: String,\n  event_version event_version: String,\n  aggregate_type aggregate_type: String,\n  entity_encoder entity_encoder: fn(b) -&gt; String,\n  entity_decoder entity_decoder: Decoder(b),\n) -&gt; EventStore(SqliteStore(b, c, a, d), b, c, a, d, Connection)\n\nSynonyms:\neventsourcing_sqlite.new\neventsourcing_sqlite new","url":"eventsourcing_sqlite.html#new"},{"doc":"eventsourcing_sqlite","title":"eventsourcing_sqlite","content":"","url":"eventsourcing_sqlite.html"}]);